# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AllowedProtocolsTacacsArgs', 'AllowedProtocolsTacacs']

@pulumi.input_type
class AllowedProtocolsTacacsArgs:
    def __init__(__self__, *,
                 allow_chap: pulumi.Input[_builtins.bool],
                 allow_ms_chap_v1: pulumi.Input[_builtins.bool],
                 allow_pap_ascii: pulumi.Input[_builtins.bool],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AllowedProtocolsTacacs resource.
        :param pulumi.Input[_builtins.bool] allow_chap: Allow CHAP
        :param pulumi.Input[_builtins.bool] allow_ms_chap_v1: Allow MS CHAP v1
        :param pulumi.Input[_builtins.bool] allow_pap_ascii: Allow PAP ASCII
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] name: The name of the allowed protocols
        """
        pulumi.set(__self__, "allow_chap", allow_chap)
        pulumi.set(__self__, "allow_ms_chap_v1", allow_ms_chap_v1)
        pulumi.set(__self__, "allow_pap_ascii", allow_pap_ascii)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="allowChap")
    def allow_chap(self) -> pulumi.Input[_builtins.bool]:
        """
        Allow CHAP
        """
        return pulumi.get(self, "allow_chap")

    @allow_chap.setter
    def allow_chap(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "allow_chap", value)

    @_builtins.property
    @pulumi.getter(name="allowMsChapV1")
    def allow_ms_chap_v1(self) -> pulumi.Input[_builtins.bool]:
        """
        Allow MS CHAP v1
        """
        return pulumi.get(self, "allow_ms_chap_v1")

    @allow_ms_chap_v1.setter
    def allow_ms_chap_v1(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "allow_ms_chap_v1", value)

    @_builtins.property
    @pulumi.getter(name="allowPapAscii")
    def allow_pap_ascii(self) -> pulumi.Input[_builtins.bool]:
        """
        Allow PAP ASCII
        """
        return pulumi.get(self, "allow_pap_ascii")

    @allow_pap_ascii.setter
    def allow_pap_ascii(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "allow_pap_ascii", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the allowed protocols
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _AllowedProtocolsTacacsState:
    def __init__(__self__, *,
                 allow_chap: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_ms_chap_v1: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_pap_ascii: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AllowedProtocolsTacacs resources.
        :param pulumi.Input[_builtins.bool] allow_chap: Allow CHAP
        :param pulumi.Input[_builtins.bool] allow_ms_chap_v1: Allow MS CHAP v1
        :param pulumi.Input[_builtins.bool] allow_pap_ascii: Allow PAP ASCII
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] name: The name of the allowed protocols
        """
        if allow_chap is not None:
            pulumi.set(__self__, "allow_chap", allow_chap)
        if allow_ms_chap_v1 is not None:
            pulumi.set(__self__, "allow_ms_chap_v1", allow_ms_chap_v1)
        if allow_pap_ascii is not None:
            pulumi.set(__self__, "allow_pap_ascii", allow_pap_ascii)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="allowChap")
    def allow_chap(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow CHAP
        """
        return pulumi.get(self, "allow_chap")

    @allow_chap.setter
    def allow_chap(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_chap", value)

    @_builtins.property
    @pulumi.getter(name="allowMsChapV1")
    def allow_ms_chap_v1(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow MS CHAP v1
        """
        return pulumi.get(self, "allow_ms_chap_v1")

    @allow_ms_chap_v1.setter
    def allow_ms_chap_v1(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_ms_chap_v1", value)

    @_builtins.property
    @pulumi.getter(name="allowPapAscii")
    def allow_pap_ascii(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow PAP ASCII
        """
        return pulumi.get(self, "allow_pap_ascii")

    @allow_pap_ascii.setter
    def allow_pap_ascii(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_pap_ascii", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the allowed protocols
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("ise:deviceadmin/allowedProtocolsTacacs:AllowedProtocolsTacacs")
class AllowedProtocolsTacacs(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_chap: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_ms_chap_v1: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_pap_ascii: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage a TACACS allowed protocols policy element.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.AllowedProtocolsTacacs("example",
            name="Protocols1",
            description="My allowed TACACS protocols",
            allow_pap_ascii=True,
            allow_chap=True,
            allow_ms_chap_v1=True)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:deviceadmin/allowedProtocolsTacacs:AllowedProtocolsTacacs example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_chap: Allow CHAP
        :param pulumi.Input[_builtins.bool] allow_ms_chap_v1: Allow MS CHAP v1
        :param pulumi.Input[_builtins.bool] allow_pap_ascii: Allow PAP ASCII
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] name: The name of the allowed protocols
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AllowedProtocolsTacacsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a TACACS allowed protocols policy element.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.AllowedProtocolsTacacs("example",
            name="Protocols1",
            description="My allowed TACACS protocols",
            allow_pap_ascii=True,
            allow_chap=True,
            allow_ms_chap_v1=True)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:deviceadmin/allowedProtocolsTacacs:AllowedProtocolsTacacs example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param AllowedProtocolsTacacsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AllowedProtocolsTacacsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_chap: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_ms_chap_v1: Optional[pulumi.Input[_builtins.bool]] = None,
                 allow_pap_ascii: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AllowedProtocolsTacacsArgs.__new__(AllowedProtocolsTacacsArgs)

            if allow_chap is None and not opts.urn:
                raise TypeError("Missing required property 'allow_chap'")
            __props__.__dict__["allow_chap"] = allow_chap
            if allow_ms_chap_v1 is None and not opts.urn:
                raise TypeError("Missing required property 'allow_ms_chap_v1'")
            __props__.__dict__["allow_ms_chap_v1"] = allow_ms_chap_v1
            if allow_pap_ascii is None and not opts.urn:
                raise TypeError("Missing required property 'allow_pap_ascii'")
            __props__.__dict__["allow_pap_ascii"] = allow_pap_ascii
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
        super(AllowedProtocolsTacacs, __self__).__init__(
            'ise:deviceadmin/allowedProtocolsTacacs:AllowedProtocolsTacacs',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_chap: Optional[pulumi.Input[_builtins.bool]] = None,
            allow_ms_chap_v1: Optional[pulumi.Input[_builtins.bool]] = None,
            allow_pap_ascii: Optional[pulumi.Input[_builtins.bool]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None) -> 'AllowedProtocolsTacacs':
        """
        Get an existing AllowedProtocolsTacacs resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_chap: Allow CHAP
        :param pulumi.Input[_builtins.bool] allow_ms_chap_v1: Allow MS CHAP v1
        :param pulumi.Input[_builtins.bool] allow_pap_ascii: Allow PAP ASCII
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] name: The name of the allowed protocols
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AllowedProtocolsTacacsState.__new__(_AllowedProtocolsTacacsState)

        __props__.__dict__["allow_chap"] = allow_chap
        __props__.__dict__["allow_ms_chap_v1"] = allow_ms_chap_v1
        __props__.__dict__["allow_pap_ascii"] = allow_pap_ascii
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        return AllowedProtocolsTacacs(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="allowChap")
    def allow_chap(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow CHAP
        """
        return pulumi.get(self, "allow_chap")

    @_builtins.property
    @pulumi.getter(name="allowMsChapV1")
    def allow_ms_chap_v1(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow MS CHAP v1
        """
        return pulumi.get(self, "allow_ms_chap_v1")

    @_builtins.property
    @pulumi.getter(name="allowPapAscii")
    def allow_pap_ascii(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow PAP ASCII
        """
        return pulumi.get(self, "allow_pap_ascii")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the allowed protocols
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetAllowedProtocolsTacacsResult',
    'AwaitableGetAllowedProtocolsTacacsResult',
    'get_allowed_protocols_tacacs',
    'get_allowed_protocols_tacacs_output',
]

@pulumi.output_type
class GetAllowedProtocolsTacacsResult:
    """
    A collection of values returned by getAllowedProtocolsTacacs.
    """
    def __init__(__self__, allow_chap=None, allow_ms_chap_v1=None, allow_pap_ascii=None, description=None, id=None, name=None):
        if allow_chap and not isinstance(allow_chap, bool):
            raise TypeError("Expected argument 'allow_chap' to be a bool")
        pulumi.set(__self__, "allow_chap", allow_chap)
        if allow_ms_chap_v1 and not isinstance(allow_ms_chap_v1, bool):
            raise TypeError("Expected argument 'allow_ms_chap_v1' to be a bool")
        pulumi.set(__self__, "allow_ms_chap_v1", allow_ms_chap_v1)
        if allow_pap_ascii and not isinstance(allow_pap_ascii, bool):
            raise TypeError("Expected argument 'allow_pap_ascii' to be a bool")
        pulumi.set(__self__, "allow_pap_ascii", allow_pap_ascii)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="allowChap")
    def allow_chap(self) -> _builtins.bool:
        """
        Allow CHAP
        """
        return pulumi.get(self, "allow_chap")

    @_builtins.property
    @pulumi.getter(name="allowMsChapV1")
    def allow_ms_chap_v1(self) -> _builtins.bool:
        """
        Allow MS CHAP v1
        """
        return pulumi.get(self, "allow_ms_chap_v1")

    @_builtins.property
    @pulumi.getter(name="allowPapAscii")
    def allow_pap_ascii(self) -> _builtins.bool:
        """
        Allow PAP ASCII
        """
        return pulumi.get(self, "allow_pap_ascii")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the allowed protocols
        """
        return pulumi.get(self, "name")


class AwaitableGetAllowedProtocolsTacacsResult(GetAllowedProtocolsTacacsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAllowedProtocolsTacacsResult(
            allow_chap=self.allow_chap,
            allow_ms_chap_v1=self.allow_ms_chap_v1,
            allow_pap_ascii=self.allow_pap_ascii,
            description=self.description,
            id=self.id,
            name=self.name)


def get_allowed_protocols_tacacs(id: Optional[_builtins.str] = None,
                                 name: Optional[_builtins.str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAllowedProtocolsTacacsResult:
    """
    This data source can read a TACACS allowed protocols policy element.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.deviceadmin.get_allowed_protocols_tacacs(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the allowed protocols
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:deviceadmin/getAllowedProtocolsTacacs:getAllowedProtocolsTacacs', __args__, opts=opts, typ=GetAllowedProtocolsTacacsResult).value

    return AwaitableGetAllowedProtocolsTacacsResult(
        allow_chap=pulumi.get(__ret__, 'allow_chap'),
        allow_ms_chap_v1=pulumi.get(__ret__, 'allow_ms_chap_v1'),
        allow_pap_ascii=pulumi.get(__ret__, 'allow_pap_ascii'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_allowed_protocols_tacacs_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAllowedProtocolsTacacsResult]:
    """
    This data source can read a TACACS allowed protocols policy element.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.deviceadmin.get_allowed_protocols_tacacs(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the allowed protocols
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:deviceadmin/getAllowedProtocolsTacacs:getAllowedProtocolsTacacs', __args__, opts=opts, typ=GetAllowedProtocolsTacacsResult)
    return __ret__.apply(lambda __response__: GetAllowedProtocolsTacacsResult(
        allow_chap=pulumi.get(__response__, 'allow_chap'),
        allow_ms_chap_v1=pulumi.get(__response__, 'allow_ms_chap_v1'),
        allow_pap_ascii=pulumi.get(__response__, 'allow_pap_ascii'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['UserIdentityGroupArgs', 'UserIdentityGroup']

@pulumi.input_type
class UserIdentityGroupArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a UserIdentityGroup resource.
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] name: The name of the user identity group
        :param pulumi.Input[_builtins.str] parent: Parent user identity group, e.g. `NAC Group:NAC:IdentityGroups:User Identity Groups`
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent is not None:
            pulumi.set(__self__, "parent", parent)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the user identity group
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Parent user identity group, e.g. `NAC Group:NAC:IdentityGroups:User Identity Groups`
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent", value)


@pulumi.input_type
class _UserIdentityGroupState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering UserIdentityGroup resources.
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] name: The name of the user identity group
        :param pulumi.Input[_builtins.str] parent: Parent user identity group, e.g. `NAC Group:NAC:IdentityGroups:User Identity Groups`
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent is not None:
            pulumi.set(__self__, "parent", parent)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the user identity group
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Parent user identity group, e.g. `NAC Group:NAC:IdentityGroups:User Identity Groups`
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent", value)


@pulumi.type_token("ise:identitymanagement/userIdentityGroup:UserIdentityGroup")
class UserIdentityGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage an User Identity Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.UserIdentityGroup("example",
            name="Group1",
            description="My endpoint identity group",
            parent="NAC Group:NAC:IdentityGroups:User Identity Groups")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:identitymanagement/userIdentityGroup:UserIdentityGroup example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] name: The name of the user identity group
        :param pulumi.Input[_builtins.str] parent: Parent user identity group, e.g. `NAC Group:NAC:IdentityGroups:User Identity Groups`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[UserIdentityGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage an User Identity Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.UserIdentityGroup("example",
            name="Group1",
            description="My endpoint identity group",
            parent="NAC Group:NAC:IdentityGroups:User Identity Groups")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:identitymanagement/userIdentityGroup:UserIdentityGroup example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param UserIdentityGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserIdentityGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserIdentityGroupArgs.__new__(UserIdentityGroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["parent"] = parent
        super(UserIdentityGroup, __self__).__init__(
            'ise:identitymanagement/userIdentityGroup:UserIdentityGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parent: Optional[pulumi.Input[_builtins.str]] = None) -> 'UserIdentityGroup':
        """
        Get an existing UserIdentityGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] name: The name of the user identity group
        :param pulumi.Input[_builtins.str] parent: Parent user identity group, e.g. `NAC Group:NAC:IdentityGroups:User Identity Groups`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserIdentityGroupState.__new__(_UserIdentityGroupState)

        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["parent"] = parent
        return UserIdentityGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the user identity group
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Parent user identity group, e.g. `NAC Group:NAC:IdentityGroups:User Identity Groups`
        """
        return pulumi.get(self, "parent")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IpToSgtMappingArgs', 'IpToSgtMapping']

@pulumi.input_type
class IpToSgtMappingArgs:
    def __init__(__self__, *,
                 deploy_to: Optional[pulumi.Input[_builtins.str]] = None,
                 deploy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 host_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 host_name: Optional[pulumi.Input[_builtins.str]] = None,
                 mapping_group: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 sgt: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a IpToSgtMapping resource.
        :param pulumi.Input[_builtins.str] deploy_to: Mandatory unless `mapping_group` is set or unless `deploy_type` is `ALL`
        :param pulumi.Input[_builtins.str] deploy_type: Deploy Type - Choices: `ALL`, `ND`, `NDG`
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] host_ip: Mandatory if `host_name` is empty
        :param pulumi.Input[_builtins.str] host_name: Mandatory if `host_ip` is empty
        :param pulumi.Input[_builtins.str] mapping_group: IP to SGT Mapping Group ID. Mandatory unless `sgt` and `deploy_to` and `deploy_type` are set
        :param pulumi.Input[_builtins.str] name: The name of the IP to SGT mapping
        :param pulumi.Input[_builtins.str] sgt: Trustsec Security Group ID. Mandatory unless `mapping_group` is set
        """
        if deploy_to is not None:
            pulumi.set(__self__, "deploy_to", deploy_to)
        if deploy_type is not None:
            pulumi.set(__self__, "deploy_type", deploy_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if host_ip is not None:
            pulumi.set(__self__, "host_ip", host_ip)
        if host_name is not None:
            pulumi.set(__self__, "host_name", host_name)
        if mapping_group is not None:
            pulumi.set(__self__, "mapping_group", mapping_group)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if sgt is not None:
            pulumi.set(__self__, "sgt", sgt)

    @_builtins.property
    @pulumi.getter(name="deployTo")
    def deploy_to(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Mandatory unless `mapping_group` is set or unless `deploy_type` is `ALL`
        """
        return pulumi.get(self, "deploy_to")

    @deploy_to.setter
    def deploy_to(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "deploy_to", value)

    @_builtins.property
    @pulumi.getter(name="deployType")
    def deploy_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Deploy Type - Choices: `ALL`, `ND`, `NDG`
        """
        return pulumi.get(self, "deploy_type")

    @deploy_type.setter
    def deploy_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "deploy_type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="hostIp")
    def host_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Mandatory if `host_name` is empty
        """
        return pulumi.get(self, "host_ip")

    @host_ip.setter
    def host_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "host_ip", value)

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Mandatory if `host_ip` is empty
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "host_name", value)

    @_builtins.property
    @pulumi.getter(name="mappingGroup")
    def mapping_group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IP to SGT Mapping Group ID. Mandatory unless `sgt` and `deploy_to` and `deploy_type` are set
        """
        return pulumi.get(self, "mapping_group")

    @mapping_group.setter
    def mapping_group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mapping_group", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the IP to SGT mapping
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def sgt(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Trustsec Security Group ID. Mandatory unless `mapping_group` is set
        """
        return pulumi.get(self, "sgt")

    @sgt.setter
    def sgt(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sgt", value)


@pulumi.input_type
class _IpToSgtMappingState:
    def __init__(__self__, *,
                 deploy_to: Optional[pulumi.Input[_builtins.str]] = None,
                 deploy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 host_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 host_name: Optional[pulumi.Input[_builtins.str]] = None,
                 mapping_group: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 sgt: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering IpToSgtMapping resources.
        :param pulumi.Input[_builtins.str] deploy_to: Mandatory unless `mapping_group` is set or unless `deploy_type` is `ALL`
        :param pulumi.Input[_builtins.str] deploy_type: Deploy Type - Choices: `ALL`, `ND`, `NDG`
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] host_ip: Mandatory if `host_name` is empty
        :param pulumi.Input[_builtins.str] host_name: Mandatory if `host_ip` is empty
        :param pulumi.Input[_builtins.str] mapping_group: IP to SGT Mapping Group ID. Mandatory unless `sgt` and `deploy_to` and `deploy_type` are set
        :param pulumi.Input[_builtins.str] name: The name of the IP to SGT mapping
        :param pulumi.Input[_builtins.str] sgt: Trustsec Security Group ID. Mandatory unless `mapping_group` is set
        """
        if deploy_to is not None:
            pulumi.set(__self__, "deploy_to", deploy_to)
        if deploy_type is not None:
            pulumi.set(__self__, "deploy_type", deploy_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if host_ip is not None:
            pulumi.set(__self__, "host_ip", host_ip)
        if host_name is not None:
            pulumi.set(__self__, "host_name", host_name)
        if mapping_group is not None:
            pulumi.set(__self__, "mapping_group", mapping_group)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if sgt is not None:
            pulumi.set(__self__, "sgt", sgt)

    @_builtins.property
    @pulumi.getter(name="deployTo")
    def deploy_to(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Mandatory unless `mapping_group` is set or unless `deploy_type` is `ALL`
        """
        return pulumi.get(self, "deploy_to")

    @deploy_to.setter
    def deploy_to(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "deploy_to", value)

    @_builtins.property
    @pulumi.getter(name="deployType")
    def deploy_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Deploy Type - Choices: `ALL`, `ND`, `NDG`
        """
        return pulumi.get(self, "deploy_type")

    @deploy_type.setter
    def deploy_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "deploy_type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="hostIp")
    def host_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Mandatory if `host_name` is empty
        """
        return pulumi.get(self, "host_ip")

    @host_ip.setter
    def host_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "host_ip", value)

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Mandatory if `host_ip` is empty
        """
        return pulumi.get(self, "host_name")

    @host_name.setter
    def host_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "host_name", value)

    @_builtins.property
    @pulumi.getter(name="mappingGroup")
    def mapping_group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IP to SGT Mapping Group ID. Mandatory unless `sgt` and `deploy_to` and `deploy_type` are set
        """
        return pulumi.get(self, "mapping_group")

    @mapping_group.setter
    def mapping_group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mapping_group", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the IP to SGT mapping
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def sgt(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Trustsec Security Group ID. Mandatory unless `mapping_group` is set
        """
        return pulumi.get(self, "sgt")

    @sgt.setter
    def sgt(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sgt", value)


@pulumi.type_token("ise:trustsec/ipToSgtMapping:IpToSgtMapping")
class IpToSgtMapping(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deploy_to: Optional[pulumi.Input[_builtins.str]] = None,
                 deploy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 host_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 host_name: Optional[pulumi.Input[_builtins.str]] = None,
                 mapping_group: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 sgt: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage a TrustSec IP to SGT Mapping.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.trustsec.IpToSgtMapping("example",
            name="10.0.0.1/32",
            deploy_type="ALL",
            host_ip="10.0.0.1/32",
            sgt="93e1bf00-8c01-11e6-996c-525400b48521")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:trustsec/ipToSgtMapping:IpToSgtMapping example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] deploy_to: Mandatory unless `mapping_group` is set or unless `deploy_type` is `ALL`
        :param pulumi.Input[_builtins.str] deploy_type: Deploy Type - Choices: `ALL`, `ND`, `NDG`
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] host_ip: Mandatory if `host_name` is empty
        :param pulumi.Input[_builtins.str] host_name: Mandatory if `host_ip` is empty
        :param pulumi.Input[_builtins.str] mapping_group: IP to SGT Mapping Group ID. Mandatory unless `sgt` and `deploy_to` and `deploy_type` are set
        :param pulumi.Input[_builtins.str] name: The name of the IP to SGT mapping
        :param pulumi.Input[_builtins.str] sgt: Trustsec Security Group ID. Mandatory unless `mapping_group` is set
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[IpToSgtMappingArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a TrustSec IP to SGT Mapping.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.trustsec.IpToSgtMapping("example",
            name="10.0.0.1/32",
            deploy_type="ALL",
            host_ip="10.0.0.1/32",
            sgt="93e1bf00-8c01-11e6-996c-525400b48521")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:trustsec/ipToSgtMapping:IpToSgtMapping example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param IpToSgtMappingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpToSgtMappingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deploy_to: Optional[pulumi.Input[_builtins.str]] = None,
                 deploy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 host_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 host_name: Optional[pulumi.Input[_builtins.str]] = None,
                 mapping_group: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 sgt: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpToSgtMappingArgs.__new__(IpToSgtMappingArgs)

            __props__.__dict__["deploy_to"] = deploy_to
            __props__.__dict__["deploy_type"] = deploy_type
            __props__.__dict__["description"] = description
            __props__.__dict__["host_ip"] = host_ip
            __props__.__dict__["host_name"] = host_name
            __props__.__dict__["mapping_group"] = mapping_group
            __props__.__dict__["name"] = name
            __props__.__dict__["sgt"] = sgt
        super(IpToSgtMapping, __self__).__init__(
            'ise:trustsec/ipToSgtMapping:IpToSgtMapping',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            deploy_to: Optional[pulumi.Input[_builtins.str]] = None,
            deploy_type: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            host_ip: Optional[pulumi.Input[_builtins.str]] = None,
            host_name: Optional[pulumi.Input[_builtins.str]] = None,
            mapping_group: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            sgt: Optional[pulumi.Input[_builtins.str]] = None) -> 'IpToSgtMapping':
        """
        Get an existing IpToSgtMapping resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] deploy_to: Mandatory unless `mapping_group` is set or unless `deploy_type` is `ALL`
        :param pulumi.Input[_builtins.str] deploy_type: Deploy Type - Choices: `ALL`, `ND`, `NDG`
        :param pulumi.Input[_builtins.str] description: Description
        :param pulumi.Input[_builtins.str] host_ip: Mandatory if `host_name` is empty
        :param pulumi.Input[_builtins.str] host_name: Mandatory if `host_ip` is empty
        :param pulumi.Input[_builtins.str] mapping_group: IP to SGT Mapping Group ID. Mandatory unless `sgt` and `deploy_to` and `deploy_type` are set
        :param pulumi.Input[_builtins.str] name: The name of the IP to SGT mapping
        :param pulumi.Input[_builtins.str] sgt: Trustsec Security Group ID. Mandatory unless `mapping_group` is set
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpToSgtMappingState.__new__(_IpToSgtMappingState)

        __props__.__dict__["deploy_to"] = deploy_to
        __props__.__dict__["deploy_type"] = deploy_type
        __props__.__dict__["description"] = description
        __props__.__dict__["host_ip"] = host_ip
        __props__.__dict__["host_name"] = host_name
        __props__.__dict__["mapping_group"] = mapping_group
        __props__.__dict__["name"] = name
        __props__.__dict__["sgt"] = sgt
        return IpToSgtMapping(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="deployTo")
    def deploy_to(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Mandatory unless `mapping_group` is set or unless `deploy_type` is `ALL`
        """
        return pulumi.get(self, "deploy_to")

    @_builtins.property
    @pulumi.getter(name="deployType")
    def deploy_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Deploy Type - Choices: `ALL`, `ND`, `NDG`
        """
        return pulumi.get(self, "deploy_type")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="hostIp")
    def host_ip(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Mandatory if `host_name` is empty
        """
        return pulumi.get(self, "host_ip")

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Mandatory if `host_ip` is empty
        """
        return pulumi.get(self, "host_name")

    @_builtins.property
    @pulumi.getter(name="mappingGroup")
    def mapping_group(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        IP to SGT Mapping Group ID. Mandatory unless `sgt` and `deploy_to` and `deploy_type` are set
        """
        return pulumi.get(self, "mapping_group")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the IP to SGT mapping
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def sgt(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Trustsec Security Group ID. Mandatory unless `mapping_group` is set
        """
        return pulumi.get(self, "sgt")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetIpToSgtMappingResult',
    'AwaitableGetIpToSgtMappingResult',
    'get_ip_to_sgt_mapping',
    'get_ip_to_sgt_mapping_output',
]

@pulumi.output_type
class GetIpToSgtMappingResult:
    """
    A collection of values returned by getIpToSgtMapping.
    """
    def __init__(__self__, deploy_to=None, deploy_type=None, description=None, host_ip=None, host_name=None, id=None, mapping_group=None, name=None, sgt=None):
        if deploy_to and not isinstance(deploy_to, str):
            raise TypeError("Expected argument 'deploy_to' to be a str")
        pulumi.set(__self__, "deploy_to", deploy_to)
        if deploy_type and not isinstance(deploy_type, str):
            raise TypeError("Expected argument 'deploy_type' to be a str")
        pulumi.set(__self__, "deploy_type", deploy_type)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if host_ip and not isinstance(host_ip, str):
            raise TypeError("Expected argument 'host_ip' to be a str")
        pulumi.set(__self__, "host_ip", host_ip)
        if host_name and not isinstance(host_name, str):
            raise TypeError("Expected argument 'host_name' to be a str")
        pulumi.set(__self__, "host_name", host_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if mapping_group and not isinstance(mapping_group, str):
            raise TypeError("Expected argument 'mapping_group' to be a str")
        pulumi.set(__self__, "mapping_group", mapping_group)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if sgt and not isinstance(sgt, str):
            raise TypeError("Expected argument 'sgt' to be a str")
        pulumi.set(__self__, "sgt", sgt)

    @_builtins.property
    @pulumi.getter(name="deployTo")
    def deploy_to(self) -> _builtins.str:
        """
        Mandatory unless `mapping_group` is set or unless `deploy_type` is `ALL`
        """
        return pulumi.get(self, "deploy_to")

    @_builtins.property
    @pulumi.getter(name="deployType")
    def deploy_type(self) -> _builtins.str:
        """
        Deploy Type
        """
        return pulumi.get(self, "deploy_type")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="hostIp")
    def host_ip(self) -> _builtins.str:
        """
        Mandatory if `host_name` is empty
        """
        return pulumi.get(self, "host_ip")

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> _builtins.str:
        """
        Mandatory if `host_ip` is empty
        """
        return pulumi.get(self, "host_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="mappingGroup")
    def mapping_group(self) -> _builtins.str:
        """
        IP to SGT Mapping Group ID. Mandatory unless `sgt` and `deploy_to` and `deploy_type` are set
        """
        return pulumi.get(self, "mapping_group")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the IP to SGT mapping
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def sgt(self) -> _builtins.str:
        """
        Trustsec Security Group ID. Mandatory unless `mapping_group` is set
        """
        return pulumi.get(self, "sgt")


class AwaitableGetIpToSgtMappingResult(GetIpToSgtMappingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpToSgtMappingResult(
            deploy_to=self.deploy_to,
            deploy_type=self.deploy_type,
            description=self.description,
            host_ip=self.host_ip,
            host_name=self.host_name,
            id=self.id,
            mapping_group=self.mapping_group,
            name=self.name,
            sgt=self.sgt)


def get_ip_to_sgt_mapping(id: Optional[_builtins.str] = None,
                          name: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpToSgtMappingResult:
    """
    This data source can read the TrustSec IP to SGT Mapping.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.trustsec.get_ip_to_sgt_mapping(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the IP to SGT mapping
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:trustsec/getIpToSgtMapping:getIpToSgtMapping', __args__, opts=opts, typ=GetIpToSgtMappingResult).value

    return AwaitableGetIpToSgtMappingResult(
        deploy_to=pulumi.get(__ret__, 'deploy_to'),
        deploy_type=pulumi.get(__ret__, 'deploy_type'),
        description=pulumi.get(__ret__, 'description'),
        host_ip=pulumi.get(__ret__, 'host_ip'),
        host_name=pulumi.get(__ret__, 'host_name'),
        id=pulumi.get(__ret__, 'id'),
        mapping_group=pulumi.get(__ret__, 'mapping_group'),
        name=pulumi.get(__ret__, 'name'),
        sgt=pulumi.get(__ret__, 'sgt'))
def get_ip_to_sgt_mapping_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIpToSgtMappingResult]:
    """
    This data source can read the TrustSec IP to SGT Mapping.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.trustsec.get_ip_to_sgt_mapping(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the IP to SGT mapping
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:trustsec/getIpToSgtMapping:getIpToSgtMapping', __args__, opts=opts, typ=GetIpToSgtMappingResult)
    return __ret__.apply(lambda __response__: GetIpToSgtMappingResult(
        deploy_to=pulumi.get(__response__, 'deploy_to'),
        deploy_type=pulumi.get(__response__, 'deploy_type'),
        description=pulumi.get(__response__, 'description'),
        host_ip=pulumi.get(__response__, 'host_ip'),
        host_name=pulumi.get(__response__, 'host_name'),
        id=pulumi.get(__response__, 'id'),
        mapping_group=pulumi.get(__response__, 'mapping_group'),
        name=pulumi.get(__response__, 'name'),
        sgt=pulumi.get(__response__, 'sgt')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTacacsCommandSetResult',
    'AwaitableGetTacacsCommandSetResult',
    'get_tacacs_command_set',
    'get_tacacs_command_set_output',
]

@pulumi.output_type
class GetTacacsCommandSetResult:
    """
    A collection of values returned by getTacacsCommandSet.
    """
    def __init__(__self__, commands=None, description=None, id=None, name=None, permit_unmatched=None):
        if commands and not isinstance(commands, list):
            raise TypeError("Expected argument 'commands' to be a list")
        pulumi.set(__self__, "commands", commands)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if permit_unmatched and not isinstance(permit_unmatched, bool):
            raise TypeError("Expected argument 'permit_unmatched' to be a bool")
        pulumi.set(__self__, "permit_unmatched", permit_unmatched)

    @_builtins.property
    @pulumi.getter
    def commands(self) -> Sequence['outputs.GetTacacsCommandSetCommandResult']:
        return pulumi.get(self, "commands")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the TACACS command set
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="permitUnmatched")
    def permit_unmatched(self) -> _builtins.bool:
        """
        Permit unmatched commands
        """
        return pulumi.get(self, "permit_unmatched")


class AwaitableGetTacacsCommandSetResult(GetTacacsCommandSetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTacacsCommandSetResult(
            commands=self.commands,
            description=self.description,
            id=self.id,
            name=self.name,
            permit_unmatched=self.permit_unmatched)


def get_tacacs_command_set(id: Optional[_builtins.str] = None,
                           name: Optional[_builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTacacsCommandSetResult:
    """
    This data source can read the TACACS Command Set.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.deviceadmin.get_tacacs_command_set(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the TACACS command set
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:deviceadmin/getTacacsCommandSet:getTacacsCommandSet', __args__, opts=opts, typ=GetTacacsCommandSetResult).value

    return AwaitableGetTacacsCommandSetResult(
        commands=pulumi.get(__ret__, 'commands'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        permit_unmatched=pulumi.get(__ret__, 'permit_unmatched'))
def get_tacacs_command_set_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTacacsCommandSetResult]:
    """
    This data source can read the TACACS Command Set.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.deviceadmin.get_tacacs_command_set(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the TACACS command set
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:deviceadmin/getTacacsCommandSet:getTacacsCommandSet', __args__, opts=opts, typ=GetTacacsCommandSetResult)
    return __ret__.apply(lambda __response__: GetTacacsCommandSetResult(
        commands=pulumi.get(__response__, 'commands'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        permit_unmatched=pulumi.get(__response__, 'permit_unmatched')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetCertificateAuthenticationProfileResult',
    'AwaitableGetCertificateAuthenticationProfileResult',
    'get_certificate_authentication_profile',
    'get_certificate_authentication_profile_output',
]

@pulumi.output_type
class GetCertificateAuthenticationProfileResult:
    """
    A collection of values returned by getCertificateAuthenticationProfile.
    """
    def __init__(__self__, allowed_as_user_name=None, certificate_attribute_name=None, description=None, external_identity_store_name=None, id=None, match_mode=None, name=None, username_from=None):
        if allowed_as_user_name and not isinstance(allowed_as_user_name, bool):
            raise TypeError("Expected argument 'allowed_as_user_name' to be a bool")
        pulumi.set(__self__, "allowed_as_user_name", allowed_as_user_name)
        if certificate_attribute_name and not isinstance(certificate_attribute_name, str):
            raise TypeError("Expected argument 'certificate_attribute_name' to be a str")
        pulumi.set(__self__, "certificate_attribute_name", certificate_attribute_name)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if external_identity_store_name and not isinstance(external_identity_store_name, str):
            raise TypeError("Expected argument 'external_identity_store_name' to be a str")
        pulumi.set(__self__, "external_identity_store_name", external_identity_store_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if match_mode and not isinstance(match_mode, str):
            raise TypeError("Expected argument 'match_mode' to be a str")
        pulumi.set(__self__, "match_mode", match_mode)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if username_from and not isinstance(username_from, str):
            raise TypeError("Expected argument 'username_from' to be a str")
        pulumi.set(__self__, "username_from", username_from)

    @_builtins.property
    @pulumi.getter(name="allowedAsUserName")
    def allowed_as_user_name(self) -> _builtins.bool:
        """
        Allow as username
        """
        return pulumi.get(self, "allowed_as_user_name")

    @_builtins.property
    @pulumi.getter(name="certificateAttributeName")
    def certificate_attribute_name(self) -> _builtins.str:
        """
        Attribute name of the Certificate Profile - used only when CERTIFICATE is chosen in `username_from`.
        """
        return pulumi.get(self, "certificate_attribute_name")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="externalIdentityStoreName")
    def external_identity_store_name(self) -> _builtins.str:
        """
        Referred IDStore name for the Certificate Profile or `[not applicable]` in case no identity store is chosen
        """
        return pulumi.get(self, "external_identity_store_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="matchMode")
    def match_mode(self) -> _builtins.str:
        """
        Match mode of the Certificate Profile. Allowed values: NEVER, RESOLVE*IDENTITY*AMBIGUITY, BINARY_COMPARISON
        """
        return pulumi.get(self, "match_mode")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the certificate profile
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="usernameFrom")
    def username_from(self) -> _builtins.str:
        """
        The attribute in the certificate where the user name should be taken from. Allowed values: `CERTIFICATE` (for a specific attribute as defined in certificateAttributeName), `UPN` (for using any Subject or Alternative Name Attributes in the Certificate - an option only in AD)
        """
        return pulumi.get(self, "username_from")


class AwaitableGetCertificateAuthenticationProfileResult(GetCertificateAuthenticationProfileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCertificateAuthenticationProfileResult(
            allowed_as_user_name=self.allowed_as_user_name,
            certificate_attribute_name=self.certificate_attribute_name,
            description=self.description,
            external_identity_store_name=self.external_identity_store_name,
            id=self.id,
            match_mode=self.match_mode,
            name=self.name,
            username_from=self.username_from)


def get_certificate_authentication_profile(id: Optional[_builtins.str] = None,
                                           name: Optional[_builtins.str] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCertificateAuthenticationProfileResult:
    """
    This data source can read the Certificate Authentication Profile.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_certificate_authentication_profile(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the certificate profile
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:identitymanagement/getCertificateAuthenticationProfile:getCertificateAuthenticationProfile', __args__, opts=opts, typ=GetCertificateAuthenticationProfileResult).value

    return AwaitableGetCertificateAuthenticationProfileResult(
        allowed_as_user_name=pulumi.get(__ret__, 'allowed_as_user_name'),
        certificate_attribute_name=pulumi.get(__ret__, 'certificate_attribute_name'),
        description=pulumi.get(__ret__, 'description'),
        external_identity_store_name=pulumi.get(__ret__, 'external_identity_store_name'),
        id=pulumi.get(__ret__, 'id'),
        match_mode=pulumi.get(__ret__, 'match_mode'),
        name=pulumi.get(__ret__, 'name'),
        username_from=pulumi.get(__ret__, 'username_from'))
def get_certificate_authentication_profile_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                  name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCertificateAuthenticationProfileResult]:
    """
    This data source can read the Certificate Authentication Profile.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_certificate_authentication_profile(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the certificate profile
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:identitymanagement/getCertificateAuthenticationProfile:getCertificateAuthenticationProfile', __args__, opts=opts, typ=GetCertificateAuthenticationProfileResult)
    return __ret__.apply(lambda __response__: GetCertificateAuthenticationProfileResult(
        allowed_as_user_name=pulumi.get(__response__, 'allowed_as_user_name'),
        certificate_attribute_name=pulumi.get(__response__, 'certificate_attribute_name'),
        description=pulumi.get(__response__, 'description'),
        external_identity_store_name=pulumi.get(__response__, 'external_identity_store_name'),
        id=pulumi.get(__response__, 'id'),
        match_mode=pulumi.get(__response__, 'match_mode'),
        name=pulumi.get(__response__, 'name'),
        username_from=pulumi.get(__response__, 'username_from')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EndpointCustomAttributeArgs', 'EndpointCustomAttribute']

@pulumi.input_type
class EndpointCustomAttributeArgs:
    def __init__(__self__, *,
                 attribute_name: pulumi.Input[_builtins.str],
                 attribute_type: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a EndpointCustomAttribute resource.
        :param pulumi.Input[_builtins.str] attribute_name: The name of the attribute
        :param pulumi.Input[_builtins.str] attribute_type: Attribute type - Choices: `Boolean`, `Date`, `Float`, `IP`, `Int`, `Long`, `String`
        """
        pulumi.set(__self__, "attribute_name", attribute_name)
        pulumi.set(__self__, "attribute_type", attribute_type)

    @_builtins.property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the attribute
        """
        return pulumi.get(self, "attribute_name")

    @attribute_name.setter
    def attribute_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "attribute_name", value)

    @_builtins.property
    @pulumi.getter(name="attributeType")
    def attribute_type(self) -> pulumi.Input[_builtins.str]:
        """
        Attribute type - Choices: `Boolean`, `Date`, `Float`, `IP`, `Int`, `Long`, `String`
        """
        return pulumi.get(self, "attribute_type")

    @attribute_type.setter
    def attribute_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "attribute_type", value)


@pulumi.input_type
class _EndpointCustomAttributeState:
    def __init__(__self__, *,
                 attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 attribute_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EndpointCustomAttribute resources.
        :param pulumi.Input[_builtins.str] attribute_name: The name of the attribute
        :param pulumi.Input[_builtins.str] attribute_type: Attribute type - Choices: `Boolean`, `Date`, `Float`, `IP`, `Int`, `Long`, `String`
        """
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_type is not None:
            pulumi.set(__self__, "attribute_type", attribute_type)

    @_builtins.property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the attribute
        """
        return pulumi.get(self, "attribute_name")

    @attribute_name.setter
    def attribute_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "attribute_name", value)

    @_builtins.property
    @pulumi.getter(name="attributeType")
    def attribute_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Attribute type - Choices: `Boolean`, `Date`, `Float`, `IP`, `Int`, `Long`, `String`
        """
        return pulumi.get(self, "attribute_type")

    @attribute_type.setter
    def attribute_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "attribute_type", value)


@pulumi.type_token("ise:identitymanagement/endpointCustomAttribute:EndpointCustomAttribute")
class EndpointCustomAttribute(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 attribute_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage an Endpoint Custom Attribute.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.EndpointCustomAttribute("example",
            attribute_name="isMobile",
            attribute_type="Boolean")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:identitymanagement/endpointCustomAttribute:EndpointCustomAttribute example "isMobile"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] attribute_name: The name of the attribute
        :param pulumi.Input[_builtins.str] attribute_type: Attribute type - Choices: `Boolean`, `Date`, `Float`, `IP`, `Int`, `Long`, `String`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EndpointCustomAttributeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage an Endpoint Custom Attribute.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.EndpointCustomAttribute("example",
            attribute_name="isMobile",
            attribute_type="Boolean")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:identitymanagement/endpointCustomAttribute:EndpointCustomAttribute example "isMobile"
        ```

        :param str resource_name: The name of the resource.
        :param EndpointCustomAttributeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndpointCustomAttributeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 attribute_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndpointCustomAttributeArgs.__new__(EndpointCustomAttributeArgs)

            if attribute_name is None and not opts.urn:
                raise TypeError("Missing required property 'attribute_name'")
            __props__.__dict__["attribute_name"] = attribute_name
            if attribute_type is None and not opts.urn:
                raise TypeError("Missing required property 'attribute_type'")
            __props__.__dict__["attribute_type"] = attribute_type
        super(EndpointCustomAttribute, __self__).__init__(
            'ise:identitymanagement/endpointCustomAttribute:EndpointCustomAttribute',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
            attribute_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'EndpointCustomAttribute':
        """
        Get an existing EndpointCustomAttribute resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] attribute_name: The name of the attribute
        :param pulumi.Input[_builtins.str] attribute_type: Attribute type - Choices: `Boolean`, `Date`, `Float`, `IP`, `Int`, `Long`, `String`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndpointCustomAttributeState.__new__(_EndpointCustomAttributeState)

        __props__.__dict__["attribute_name"] = attribute_name
        __props__.__dict__["attribute_type"] = attribute_type
        return EndpointCustomAttribute(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the attribute
        """
        return pulumi.get(self, "attribute_name")

    @_builtins.property
    @pulumi.getter(name="attributeType")
    def attribute_type(self) -> pulumi.Output[_builtins.str]:
        """
        Attribute type - Choices: `Boolean`, `Date`, `Float`, `IP`, `Int`, `Long`, `String`
        """
        return pulumi.get(self, "attribute_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DeviceIpArgs',
    'DeviceIpArgsDict',
]

MYPY = False

if not MYPY:
    class DeviceIpArgsDict(TypedDict):
        ipaddress: pulumi.Input[_builtins.str]
        """
        It can be either single ip address or ip range address
        """
        ipaddress_exclude: NotRequired[pulumi.Input[_builtins.str]]
        """
        It can be either single ip address or ip range address
        """
        mask: NotRequired[pulumi.Input[_builtins.str]]
        """
        Subnet mask length
        """
elif False:
    DeviceIpArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DeviceIpArgs:
    def __init__(__self__, *,
                 ipaddress: pulumi.Input[_builtins.str],
                 ipaddress_exclude: Optional[pulumi.Input[_builtins.str]] = None,
                 mask: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] ipaddress: It can be either single ip address or ip range address
        :param pulumi.Input[_builtins.str] ipaddress_exclude: It can be either single ip address or ip range address
        :param pulumi.Input[_builtins.str] mask: Subnet mask length
        """
        pulumi.set(__self__, "ipaddress", ipaddress)
        if ipaddress_exclude is not None:
            pulumi.set(__self__, "ipaddress_exclude", ipaddress_exclude)
        if mask is not None:
            pulumi.set(__self__, "mask", mask)

    @_builtins.property
    @pulumi.getter
    def ipaddress(self) -> pulumi.Input[_builtins.str]:
        """
        It can be either single ip address or ip range address
        """
        return pulumi.get(self, "ipaddress")

    @ipaddress.setter
    def ipaddress(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "ipaddress", value)

    @_builtins.property
    @pulumi.getter(name="ipaddressExclude")
    def ipaddress_exclude(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        It can be either single ip address or ip range address
        """
        return pulumi.get(self, "ipaddress_exclude")

    @ipaddress_exclude.setter
    def ipaddress_exclude(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipaddress_exclude", value)

    @_builtins.property
    @pulumi.getter
    def mask(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Subnet mask length
        """
        return pulumi.get(self, "mask")

    @mask.setter
    def mask(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mask", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAuthorizationExceptionRuleResult',
    'AwaitableGetAuthorizationExceptionRuleResult',
    'get_authorization_exception_rule',
    'get_authorization_exception_rule_output',
]

@pulumi.output_type
class GetAuthorizationExceptionRuleResult:
    """
    A collection of values returned by getAuthorizationExceptionRule.
    """
    def __init__(__self__, childrens=None, condition_attribute_name=None, condition_attribute_value=None, condition_dictionary_name=None, condition_dictionary_value=None, condition_id=None, condition_is_negate=None, condition_operator=None, condition_type=None, default=None, id=None, name=None, policy_set_id=None, profiles=None, rank=None, security_group=None, state=None):
        if childrens and not isinstance(childrens, list):
            raise TypeError("Expected argument 'childrens' to be a list")
        pulumi.set(__self__, "childrens", childrens)
        if condition_attribute_name and not isinstance(condition_attribute_name, str):
            raise TypeError("Expected argument 'condition_attribute_name' to be a str")
        pulumi.set(__self__, "condition_attribute_name", condition_attribute_name)
        if condition_attribute_value and not isinstance(condition_attribute_value, str):
            raise TypeError("Expected argument 'condition_attribute_value' to be a str")
        pulumi.set(__self__, "condition_attribute_value", condition_attribute_value)
        if condition_dictionary_name and not isinstance(condition_dictionary_name, str):
            raise TypeError("Expected argument 'condition_dictionary_name' to be a str")
        pulumi.set(__self__, "condition_dictionary_name", condition_dictionary_name)
        if condition_dictionary_value and not isinstance(condition_dictionary_value, str):
            raise TypeError("Expected argument 'condition_dictionary_value' to be a str")
        pulumi.set(__self__, "condition_dictionary_value", condition_dictionary_value)
        if condition_id and not isinstance(condition_id, str):
            raise TypeError("Expected argument 'condition_id' to be a str")
        pulumi.set(__self__, "condition_id", condition_id)
        if condition_is_negate and not isinstance(condition_is_negate, bool):
            raise TypeError("Expected argument 'condition_is_negate' to be a bool")
        pulumi.set(__self__, "condition_is_negate", condition_is_negate)
        if condition_operator and not isinstance(condition_operator, str):
            raise TypeError("Expected argument 'condition_operator' to be a str")
        pulumi.set(__self__, "condition_operator", condition_operator)
        if condition_type and not isinstance(condition_type, str):
            raise TypeError("Expected argument 'condition_type' to be a str")
        pulumi.set(__self__, "condition_type", condition_type)
        if default and not isinstance(default, bool):
            raise TypeError("Expected argument 'default' to be a bool")
        pulumi.set(__self__, "default", default)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if policy_set_id and not isinstance(policy_set_id, str):
            raise TypeError("Expected argument 'policy_set_id' to be a str")
        pulumi.set(__self__, "policy_set_id", policy_set_id)
        if profiles and not isinstance(profiles, list):
            raise TypeError("Expected argument 'profiles' to be a list")
        pulumi.set(__self__, "profiles", profiles)
        if rank and not isinstance(rank, int):
            raise TypeError("Expected argument 'rank' to be a int")
        pulumi.set(__self__, "rank", rank)
        if security_group and not isinstance(security_group, str):
            raise TypeError("Expected argument 'security_group' to be a str")
        pulumi.set(__self__, "security_group", security_group)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter
    def childrens(self) -> Sequence['outputs.GetAuthorizationExceptionRuleChildrenResult']:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @_builtins.property
    @pulumi.getter(name="conditionAttributeName")
    def condition_attribute_name(self) -> _builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "condition_attribute_name")

    @_builtins.property
    @pulumi.getter(name="conditionAttributeValue")
    def condition_attribute_value(self) -> _builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "condition_attribute_value")

    @_builtins.property
    @pulumi.getter(name="conditionDictionaryName")
    def condition_dictionary_name(self) -> _builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "condition_dictionary_name")

    @_builtins.property
    @pulumi.getter(name="conditionDictionaryValue")
    def condition_dictionary_value(self) -> _builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "condition_dictionary_value")

    @_builtins.property
    @pulumi.getter(name="conditionId")
    def condition_id(self) -> _builtins.str:
        """
        UUID for condition
        """
        return pulumi.get(self, "condition_id")

    @_builtins.property
    @pulumi.getter(name="conditionIsNegate")
    def condition_is_negate(self) -> _builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "condition_is_negate")

    @_builtins.property
    @pulumi.getter(name="conditionOperator")
    def condition_operator(self) -> _builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "condition_operator")

    @_builtins.property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> _builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        """
        return pulumi.get(self, "condition_type")

    @_builtins.property
    @pulumi.getter
    def default(self) -> _builtins.bool:
        """
        Indicates if this rule is the default one
        """
        return pulumi.get(self, "default")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Rule name, [Valid characters are alphanumerics, underscore, hyphen, space, period, parentheses]
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="policySetId")
    def policy_set_id(self) -> _builtins.str:
        """
        Policy set ID
        """
        return pulumi.get(self, "policy_set_id")

    @_builtins.property
    @pulumi.getter
    def profiles(self) -> Sequence[_builtins.str]:
        """
        The authorization profile(s)
        """
        return pulumi.get(self, "profiles")

    @_builtins.property
    @pulumi.getter
    def rank(self) -> _builtins.int:
        """
        The rank (priority) in relation to other rules. Lower rank is higher priority.
        """
        return pulumi.get(self, "rank")

    @_builtins.property
    @pulumi.getter(name="securityGroup")
    def security_group(self) -> _builtins.str:
        """
        Security group used in authorization policies
        """
        return pulumi.get(self, "security_group")

    @_builtins.property
    @pulumi.getter
    def state(self) -> _builtins.str:
        """
        The state that the rule is in. A disabled rule cannot be matched.
        """
        return pulumi.get(self, "state")


class AwaitableGetAuthorizationExceptionRuleResult(GetAuthorizationExceptionRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuthorizationExceptionRuleResult(
            childrens=self.childrens,
            condition_attribute_name=self.condition_attribute_name,
            condition_attribute_value=self.condition_attribute_value,
            condition_dictionary_name=self.condition_dictionary_name,
            condition_dictionary_value=self.condition_dictionary_value,
            condition_id=self.condition_id,
            condition_is_negate=self.condition_is_negate,
            condition_operator=self.condition_operator,
            condition_type=self.condition_type,
            default=self.default,
            id=self.id,
            name=self.name,
            policy_set_id=self.policy_set_id,
            profiles=self.profiles,
            rank=self.rank,
            security_group=self.security_group,
            state=self.state)


def get_authorization_exception_rule(id: Optional[_builtins.str] = None,
                                     name: Optional[_builtins.str] = None,
                                     policy_set_id: Optional[_builtins.str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuthorizationExceptionRuleResult:
    """
    This data source can read the Network Access Authorization Exception Rule.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.networkaccess.get_authorization_exception_rule(id="76d24097-41c4-4558-a4d0-a8c07ac08470",
        policy_set_id="d82952cb-b901-4b09-b363-5ebf39bdbaf9")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: Rule name, [Valid characters are alphanumerics, underscore, hyphen, space, period, parentheses]
    :param _builtins.str policy_set_id: Policy set ID
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['policySetId'] = policy_set_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:networkaccess/getAuthorizationExceptionRule:getAuthorizationExceptionRule', __args__, opts=opts, typ=GetAuthorizationExceptionRuleResult).value

    return AwaitableGetAuthorizationExceptionRuleResult(
        childrens=pulumi.get(__ret__, 'childrens'),
        condition_attribute_name=pulumi.get(__ret__, 'condition_attribute_name'),
        condition_attribute_value=pulumi.get(__ret__, 'condition_attribute_value'),
        condition_dictionary_name=pulumi.get(__ret__, 'condition_dictionary_name'),
        condition_dictionary_value=pulumi.get(__ret__, 'condition_dictionary_value'),
        condition_id=pulumi.get(__ret__, 'condition_id'),
        condition_is_negate=pulumi.get(__ret__, 'condition_is_negate'),
        condition_operator=pulumi.get(__ret__, 'condition_operator'),
        condition_type=pulumi.get(__ret__, 'condition_type'),
        default=pulumi.get(__ret__, 'default'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        policy_set_id=pulumi.get(__ret__, 'policy_set_id'),
        profiles=pulumi.get(__ret__, 'profiles'),
        rank=pulumi.get(__ret__, 'rank'),
        security_group=pulumi.get(__ret__, 'security_group'),
        state=pulumi.get(__ret__, 'state'))
def get_authorization_exception_rule_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            policy_set_id: Optional[pulumi.Input[_builtins.str]] = None,
                                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAuthorizationExceptionRuleResult]:
    """
    This data source can read the Network Access Authorization Exception Rule.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.networkaccess.get_authorization_exception_rule(id="76d24097-41c4-4558-a4d0-a8c07ac08470",
        policy_set_id="d82952cb-b901-4b09-b363-5ebf39bdbaf9")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: Rule name, [Valid characters are alphanumerics, underscore, hyphen, space, period, parentheses]
    :param _builtins.str policy_set_id: Policy set ID
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['policySetId'] = policy_set_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:networkaccess/getAuthorizationExceptionRule:getAuthorizationExceptionRule', __args__, opts=opts, typ=GetAuthorizationExceptionRuleResult)
    return __ret__.apply(lambda __response__: GetAuthorizationExceptionRuleResult(
        childrens=pulumi.get(__response__, 'childrens'),
        condition_attribute_name=pulumi.get(__response__, 'condition_attribute_name'),
        condition_attribute_value=pulumi.get(__response__, 'condition_attribute_value'),
        condition_dictionary_name=pulumi.get(__response__, 'condition_dictionary_name'),
        condition_dictionary_value=pulumi.get(__response__, 'condition_dictionary_value'),
        condition_id=pulumi.get(__response__, 'condition_id'),
        condition_is_negate=pulumi.get(__response__, 'condition_is_negate'),
        condition_operator=pulumi.get(__response__, 'condition_operator'),
        condition_type=pulumi.get(__response__, 'condition_type'),
        default=pulumi.get(__response__, 'default'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        policy_set_id=pulumi.get(__response__, 'policy_set_id'),
        profiles=pulumi.get(__response__, 'profiles'),
        rank=pulumi.get(__response__, 'rank'),
        security_group=pulumi.get(__response__, 'security_group'),
        state=pulumi.get(__response__, 'state')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetUserIdentityGroupResult',
    'AwaitableGetUserIdentityGroupResult',
    'get_user_identity_group',
    'get_user_identity_group_output',
]

@pulumi.output_type
class GetUserIdentityGroupResult:
    """
    A collection of values returned by getUserIdentityGroup.
    """
    def __init__(__self__, description=None, id=None, name=None, parent=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if parent and not isinstance(parent, str):
            raise TypeError("Expected argument 'parent' to be a str")
        pulumi.set(__self__, "parent", parent)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the user identity group
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> _builtins.str:
        """
        Parent user identity group, e.g. `NAC Group:NAC:IdentityGroups:User Identity Groups`
        """
        return pulumi.get(self, "parent")


class AwaitableGetUserIdentityGroupResult(GetUserIdentityGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserIdentityGroupResult(
            description=self.description,
            id=self.id,
            name=self.name,
            parent=self.parent)


def get_user_identity_group(id: Optional[_builtins.str] = None,
                            name: Optional[_builtins.str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserIdentityGroupResult:
    """
    This data source can read the User Identity Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_user_identity_group(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the user identity group
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:identitymanagement/getUserIdentityGroup:getUserIdentityGroup', __args__, opts=opts, typ=GetUserIdentityGroupResult).value

    return AwaitableGetUserIdentityGroupResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        parent=pulumi.get(__ret__, 'parent'))
def get_user_identity_group_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserIdentityGroupResult]:
    """
    This data source can read the User Identity Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_user_identity_group(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the user identity group
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:identitymanagement/getUserIdentityGroup:getUserIdentityGroup', __args__, opts=opts, typ=GetUserIdentityGroupResult)
    return __ret__.apply(lambda __response__: GetUserIdentityGroupResult(
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        parent=pulumi.get(__response__, 'parent')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetTimeAndDateConditionResult',
    'AwaitableGetTimeAndDateConditionResult',
    'get_time_and_date_condition',
    'get_time_and_date_condition_output',
]

@pulumi.output_type
class GetTimeAndDateConditionResult:
    """
    A collection of values returned by getTimeAndDateCondition.
    """
    def __init__(__self__, description=None, end_date=None, end_time=None, exception_end_date=None, exception_end_time=None, exception_start_date=None, exception_start_time=None, id=None, is_negate=None, name=None, start_date=None, start_time=None, week_days=None, week_days_exceptions=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if end_date and not isinstance(end_date, str):
            raise TypeError("Expected argument 'end_date' to be a str")
        pulumi.set(__self__, "end_date", end_date)
        if end_time and not isinstance(end_time, str):
            raise TypeError("Expected argument 'end_time' to be a str")
        pulumi.set(__self__, "end_time", end_time)
        if exception_end_date and not isinstance(exception_end_date, str):
            raise TypeError("Expected argument 'exception_end_date' to be a str")
        pulumi.set(__self__, "exception_end_date", exception_end_date)
        if exception_end_time and not isinstance(exception_end_time, str):
            raise TypeError("Expected argument 'exception_end_time' to be a str")
        pulumi.set(__self__, "exception_end_time", exception_end_time)
        if exception_start_date and not isinstance(exception_start_date, str):
            raise TypeError("Expected argument 'exception_start_date' to be a str")
        pulumi.set(__self__, "exception_start_date", exception_start_date)
        if exception_start_time and not isinstance(exception_start_time, str):
            raise TypeError("Expected argument 'exception_start_time' to be a str")
        pulumi.set(__self__, "exception_start_time", exception_start_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_negate and not isinstance(is_negate, bool):
            raise TypeError("Expected argument 'is_negate' to be a bool")
        pulumi.set(__self__, "is_negate", is_negate)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if start_date and not isinstance(start_date, str):
            raise TypeError("Expected argument 'start_date' to be a str")
        pulumi.set(__self__, "start_date", start_date)
        if start_time and not isinstance(start_time, str):
            raise TypeError("Expected argument 'start_time' to be a str")
        pulumi.set(__self__, "start_time", start_time)
        if week_days and not isinstance(week_days, list):
            raise TypeError("Expected argument 'week_days' to be a list")
        pulumi.set(__self__, "week_days", week_days)
        if week_days_exceptions and not isinstance(week_days_exceptions, list):
            raise TypeError("Expected argument 'week_days_exceptions' to be a list")
        pulumi.set(__self__, "week_days_exceptions", week_days_exceptions)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="endDate")
    def end_date(self) -> _builtins.str:
        """
        End date
        """
        return pulumi.get(self, "end_date")

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> _builtins.str:
        """
        End time
        """
        return pulumi.get(self, "end_time")

    @_builtins.property
    @pulumi.getter(name="exceptionEndDate")
    def exception_end_date(self) -> _builtins.str:
        """
        Exception end date
        """
        return pulumi.get(self, "exception_end_date")

    @_builtins.property
    @pulumi.getter(name="exceptionEndTime")
    def exception_end_time(self) -> _builtins.str:
        """
        Exception end time
        """
        return pulumi.get(self, "exception_end_time")

    @_builtins.property
    @pulumi.getter(name="exceptionStartDate")
    def exception_start_date(self) -> _builtins.str:
        """
        Exception start date
        """
        return pulumi.get(self, "exception_start_date")

    @_builtins.property
    @pulumi.getter(name="exceptionStartTime")
    def exception_start_time(self) -> _builtins.str:
        """
        Exception start time
        """
        return pulumi.get(self, "exception_start_time")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> _builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="startDate")
    def start_date(self) -> _builtins.str:
        """
        Start date
        """
        return pulumi.get(self, "start_date")

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> _builtins.str:
        """
        Start time
        """
        return pulumi.get(self, "start_time")

    @_builtins.property
    @pulumi.getter(name="weekDays")
    def week_days(self) -> Sequence[_builtins.str]:
        """
        Defines for which days this condition will be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`. Default - List of all week days.
        """
        return pulumi.get(self, "week_days")

    @_builtins.property
    @pulumi.getter(name="weekDaysExceptions")
    def week_days_exceptions(self) -> Sequence[_builtins.str]:
        """
        Defines for which days this condition will NOT be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`.
        """
        return pulumi.get(self, "week_days_exceptions")


class AwaitableGetTimeAndDateConditionResult(GetTimeAndDateConditionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTimeAndDateConditionResult(
            description=self.description,
            end_date=self.end_date,
            end_time=self.end_time,
            exception_end_date=self.exception_end_date,
            exception_end_time=self.exception_end_time,
            exception_start_date=self.exception_start_date,
            exception_start_time=self.exception_start_time,
            id=self.id,
            is_negate=self.is_negate,
            name=self.name,
            start_date=self.start_date,
            start_time=self.start_time,
            week_days=self.week_days,
            week_days_exceptions=self.week_days_exceptions)


def get_time_and_date_condition(id: Optional[_builtins.str] = None,
                                name: Optional[_builtins.str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTimeAndDateConditionResult:
    """
    This data source can read the Device Admin Time And Date Condition.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.deviceadmin.get_time_and_date_condition(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: Condition name
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:deviceadmin/getTimeAndDateCondition:getTimeAndDateCondition', __args__, opts=opts, typ=GetTimeAndDateConditionResult).value

    return AwaitableGetTimeAndDateConditionResult(
        description=pulumi.get(__ret__, 'description'),
        end_date=pulumi.get(__ret__, 'end_date'),
        end_time=pulumi.get(__ret__, 'end_time'),
        exception_end_date=pulumi.get(__ret__, 'exception_end_date'),
        exception_end_time=pulumi.get(__ret__, 'exception_end_time'),
        exception_start_date=pulumi.get(__ret__, 'exception_start_date'),
        exception_start_time=pulumi.get(__ret__, 'exception_start_time'),
        id=pulumi.get(__ret__, 'id'),
        is_negate=pulumi.get(__ret__, 'is_negate'),
        name=pulumi.get(__ret__, 'name'),
        start_date=pulumi.get(__ret__, 'start_date'),
        start_time=pulumi.get(__ret__, 'start_time'),
        week_days=pulumi.get(__ret__, 'week_days'),
        week_days_exceptions=pulumi.get(__ret__, 'week_days_exceptions'))
def get_time_and_date_condition_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                       name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTimeAndDateConditionResult]:
    """
    This data source can read the Device Admin Time And Date Condition.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.deviceadmin.get_time_and_date_condition(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: Condition name
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:deviceadmin/getTimeAndDateCondition:getTimeAndDateCondition', __args__, opts=opts, typ=GetTimeAndDateConditionResult)
    return __ret__.apply(lambda __response__: GetTimeAndDateConditionResult(
        description=pulumi.get(__response__, 'description'),
        end_date=pulumi.get(__response__, 'end_date'),
        end_time=pulumi.get(__response__, 'end_time'),
        exception_end_date=pulumi.get(__response__, 'exception_end_date'),
        exception_end_time=pulumi.get(__response__, 'exception_end_time'),
        exception_start_date=pulumi.get(__response__, 'exception_start_date'),
        exception_start_time=pulumi.get(__response__, 'exception_start_time'),
        id=pulumi.get(__response__, 'id'),
        is_negate=pulumi.get(__response__, 'is_negate'),
        name=pulumi.get(__response__, 'name'),
        start_date=pulumi.get(__response__, 'start_date'),
        start_time=pulumi.get(__response__, 'start_time'),
        week_days=pulumi.get(__response__, 'week_days'),
        week_days_exceptions=pulumi.get(__response__, 'week_days_exceptions')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RepositoryArgs', 'Repository']

@pulumi.input_type
class RepositoryArgs:
    def __init__(__self__, *,
                 path: pulumi.Input[_builtins.str],
                 protocol: pulumi.Input[_builtins.str],
                 enable_pki: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 server_name: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Repository resource.
        :param pulumi.Input[_builtins.str] path: Path should always start with "/" and can contain alphanumeric, underscore, hyphen and dot characters.
        :param pulumi.Input[_builtins.str] protocol: Protocol - Choices: `CDROM`, `DISK`, `FTP`, `HTTP`, `HTTPS`, `NFS`, `SFTP`, `TFTP`
        :param pulumi.Input[_builtins.bool] enable_pki: Enable PKI
        :param pulumi.Input[_builtins.str] name: Repository name should be less than 80 characters and can contain alphanumeric, underscore, hyphen and dot characters.
        :param pulumi.Input[_builtins.str] password: Password can contain alphanumeric and/or special characters.
        :param pulumi.Input[_builtins.str] server_name: Name of the server
        :param pulumi.Input[_builtins.str] user_name: User name
        """
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "protocol", protocol)
        if enable_pki is not None:
            pulumi.set(__self__, "enable_pki", enable_pki)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if server_name is not None:
            pulumi.set(__self__, "server_name", server_name)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Input[_builtins.str]:
        """
        Path should always start with "/" and can contain alphanumeric, underscore, hyphen and dot characters.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[_builtins.str]:
        """
        Protocol - Choices: `CDROM`, `DISK`, `FTP`, `HTTP`, `HTTPS`, `NFS`, `SFTP`, `TFTP`
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter(name="enablePki")
    def enable_pki(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable PKI
        """
        return pulumi.get(self, "enable_pki")

    @enable_pki.setter
    def enable_pki(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_pki", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository name should be less than 80 characters and can contain alphanumeric, underscore, hyphen and dot characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password can contain alphanumeric and/or special characters.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter(name="serverName")
    def server_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the server
        """
        return pulumi.get(self, "server_name")

    @server_name.setter
    def server_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "server_name", value)

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User name
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.input_type
class _RepositoryState:
    def __init__(__self__, *,
                 enable_pki: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 server_name: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Repository resources.
        :param pulumi.Input[_builtins.bool] enable_pki: Enable PKI
        :param pulumi.Input[_builtins.str] name: Repository name should be less than 80 characters and can contain alphanumeric, underscore, hyphen and dot characters.
        :param pulumi.Input[_builtins.str] password: Password can contain alphanumeric and/or special characters.
        :param pulumi.Input[_builtins.str] path: Path should always start with "/" and can contain alphanumeric, underscore, hyphen and dot characters.
        :param pulumi.Input[_builtins.str] protocol: Protocol - Choices: `CDROM`, `DISK`, `FTP`, `HTTP`, `HTTPS`, `NFS`, `SFTP`, `TFTP`
        :param pulumi.Input[_builtins.str] server_name: Name of the server
        :param pulumi.Input[_builtins.str] user_name: User name
        """
        if enable_pki is not None:
            pulumi.set(__self__, "enable_pki", enable_pki)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if server_name is not None:
            pulumi.set(__self__, "server_name", server_name)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @_builtins.property
    @pulumi.getter(name="enablePki")
    def enable_pki(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable PKI
        """
        return pulumi.get(self, "enable_pki")

    @enable_pki.setter
    def enable_pki(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_pki", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository name should be less than 80 characters and can contain alphanumeric, underscore, hyphen and dot characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password can contain alphanumeric and/or special characters.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path should always start with "/" and can contain alphanumeric, underscore, hyphen and dot characters.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Protocol - Choices: `CDROM`, `DISK`, `FTP`, `HTTP`, `HTTPS`, `NFS`, `SFTP`, `TFTP`
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter(name="serverName")
    def server_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the server
        """
        return pulumi.get(self, "server_name")

    @server_name.setter
    def server_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "server_name", value)

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User name
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.type_token("ise:system/repository:Repository")
class Repository(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_pki: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 server_name: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage a Repository.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.system.Repository("example",
            name="repo1",
            protocol="SFTP",
            path="/dir",
            server_name="server1",
            user_name="user9",
            password="cisco123",
            enable_pki=False)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:system/repository:Repository example "repo1"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] enable_pki: Enable PKI
        :param pulumi.Input[_builtins.str] name: Repository name should be less than 80 characters and can contain alphanumeric, underscore, hyphen and dot characters.
        :param pulumi.Input[_builtins.str] password: Password can contain alphanumeric and/or special characters.
        :param pulumi.Input[_builtins.str] path: Path should always start with "/" and can contain alphanumeric, underscore, hyphen and dot characters.
        :param pulumi.Input[_builtins.str] protocol: Protocol - Choices: `CDROM`, `DISK`, `FTP`, `HTTP`, `HTTPS`, `NFS`, `SFTP`, `TFTP`
        :param pulumi.Input[_builtins.str] server_name: Name of the server
        :param pulumi.Input[_builtins.str] user_name: User name
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RepositoryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a Repository.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.system.Repository("example",
            name="repo1",
            protocol="SFTP",
            path="/dir",
            server_name="server1",
            user_name="user9",
            password="cisco123",
            enable_pki=False)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:system/repository:Repository example "repo1"
        ```

        :param str resource_name: The name of the resource.
        :param RepositoryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RepositoryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_pki: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 server_name: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RepositoryArgs.__new__(RepositoryArgs)

            __props__.__dict__["enable_pki"] = enable_pki
            __props__.__dict__["name"] = name
            __props__.__dict__["password"] = password
            if path is None and not opts.urn:
                raise TypeError("Missing required property 'path'")
            __props__.__dict__["path"] = path
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["server_name"] = server_name
            __props__.__dict__["user_name"] = user_name
        super(Repository, __self__).__init__(
            'ise:system/repository:Repository',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enable_pki: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            path: Optional[pulumi.Input[_builtins.str]] = None,
            protocol: Optional[pulumi.Input[_builtins.str]] = None,
            server_name: Optional[pulumi.Input[_builtins.str]] = None,
            user_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'Repository':
        """
        Get an existing Repository resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] enable_pki: Enable PKI
        :param pulumi.Input[_builtins.str] name: Repository name should be less than 80 characters and can contain alphanumeric, underscore, hyphen and dot characters.
        :param pulumi.Input[_builtins.str] password: Password can contain alphanumeric and/or special characters.
        :param pulumi.Input[_builtins.str] path: Path should always start with "/" and can contain alphanumeric, underscore, hyphen and dot characters.
        :param pulumi.Input[_builtins.str] protocol: Protocol - Choices: `CDROM`, `DISK`, `FTP`, `HTTP`, `HTTPS`, `NFS`, `SFTP`, `TFTP`
        :param pulumi.Input[_builtins.str] server_name: Name of the server
        :param pulumi.Input[_builtins.str] user_name: User name
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RepositoryState.__new__(_RepositoryState)

        __props__.__dict__["enable_pki"] = enable_pki
        __props__.__dict__["name"] = name
        __props__.__dict__["password"] = password
        __props__.__dict__["path"] = path
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["server_name"] = server_name
        __props__.__dict__["user_name"] = user_name
        return Repository(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="enablePki")
    def enable_pki(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable PKI
        """
        return pulumi.get(self, "enable_pki")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Repository name should be less than 80 characters and can contain alphanumeric, underscore, hyphen and dot characters.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Password can contain alphanumeric and/or special characters.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Output[_builtins.str]:
        """
        Path should always start with "/" and can contain alphanumeric, underscore, hyphen and dot characters.
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[_builtins.str]:
        """
        Protocol - Choices: `CDROM`, `DISK`, `FTP`, `HTTP`, `HTTPS`, `NFS`, `SFTP`, `TFTP`
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter(name="serverName")
    def server_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the server
        """
        return pulumi.get(self, "server_name")

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        User name
        """
        return pulumi.get(self, "user_name")

